//region Imports
const path = require('path')
const fs = require('fs')
const _ = require('lodash')
//endregion

function getConfigPath() {
  return path.join(process.cwd(), './babelator.js')
}

function getConfig() {
  // If `babelator.js` exists, grab config settings from there.
  const babelatorConfigPath = getConfigPath()
  return fs.existsSync(babelatorConfigPath) ? require(babelatorConfigPath) : {}
}

function main() {

  const opts = _.defaultsDeep({}, getConfig(), {
    srcDir: 'src',
    destDir: 'lib',
    shouldCompileTests: true,
    //eslintrc: {}
    //mocha: {},
    babel: {}
  })

  // Computed config.
  _.defaultsDeep(opts, {
    srcGlob: opts.srcDir + '/**/*.js',
    destGlob: opts.destDir + '/**/*',
    testsGlob: opts.srcDir + '/**/__tests__/**/*-test.js',
    testsDestGlob: opts.destDir + '/**/__tests__/**/*-test.js', // Transpiled tests.
  })

  ////////
  // This is shared.
  const transformAsyncToModuleMethod = require('babel-plugin-transform-async-to-module-method')
  const asyncPlugin =
    [transformAsyncToModuleMethod, {
      module: 'bluebird',
      method: 'coroutine',
    }]
  const addModuleExports = require('babel-plugin-add-module-exports')
  const transformRuntime = require('babel-plugin-transform-runtime')
  const externalHelpers = require('babel-plugin-external-helpers-2')
  const babelDefaults = {
    plugins: [externalHelpers, asyncPlugin, transformRuntime, addModuleExports],
    presets: ['es2015', 'react', 'stage-0']
  }
  ////////

  _.defaultsDeep(opts.babel, babelDefaults)

  return opts

}

main.getConfigPath = getConfigPath

module.exports = main
